/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <gtkmm.h>
#include <iostream>
#include <libglademm.h>
#include <libintl.h>
#include "mainwindow.h"
#include "globals.h"

int main(int argc, char **argv)
{  
#if defined(ENABLE_NLS)
	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
#endif //ENABLE_NLS
#if defined(_WIN32) 
    // Windows needs more initializations
    std::string base_dir = argv[0];
    if(Glib::path_is_absolute(base_dir)) {
        base_dir = Glib::path_get_dirname(base_dir) + "\\";
    } else {
        base_dir = Glib::get_current_dir() + "\\";
    }    
    glade_interface_path = base_dir + glade_interface_path;
    app_logo_path = base_dir + app_logo_path;
#endif // _WIN32
    Glib::ustring filename = "";

    if(argc > 1) {
        // need to load the file
        filename = Glib::ustring(argv[1]);
    }
    Gtk::Main m(&argc, &argv);      
	
	Glib::RefPtr<Gnome::Glade::Xml> refXml;
	try {            
		refXml = 
		Gnome::Glade::Xml::create(glade_interface_path,
							  "MainWindow");
	}
	catch(const Gnome::Glade::XmlError& ex)
	{
	   std::cerr << ex.what() << std::endl;
	   return 1;
	}

	PCalMainWindow* MainWindow = 0;
	refXml->get_widget_derived("MainWindow", MainWindow);
	if(MainWindow)
	{
        if(filename.size()) MainWindow->start_with_file(filename);
		m.run(*MainWindow);
	}        
	return 0;
}
